Contributor Agreement
=====================

The submitter agrees by adding his or her name within the section below named
"Contributors" and submitting the resulting modified document to the
canonical shared repository location for this software project (whether
directly, as a user with "direct commit access", or via a "pull request"), he
or she is signing a contract electronically.  The submitter becomes a
Contributor after a) he or she signs this document by adding their name (and company name)
beneath the "Contributors" section below, and b) the resulting document is
accepted into the canonical version control repository.

(http://www.harmonyagreements.org)

CLA_INDIVIDUAL.md is the text for contributions from individuals.

CLA_ENTITY.md is the text for contributions from legal entities.

List of Contributors
====================

The below-signed are contributors to a code repository that is part of the
project.  Each below-signed contributor has read,
understand and agrees to the terms above in the section within this document
entitled "Contributor Agreement" as of the date beside his or her name.

Current or previous core committers:

* Marcin Lulek (Ergo^) 2000-01-01

Contributors:

* Luke Crooks (crooksey) 2014-08-22
* Svintsov Dmitry (uralbash) 2014-12-24
* Marcin Kuzminski (marcinkuzminski) 2011-11-14
* Lukasz Fidosz (virhilo) 2011-01-01
* Arian Maykon de Araújo Diógenes (arianmaykon) 2016-04-19
* Edward Arghiroiu (themightyonyx) 2015-11-13
* Łukasz Bołdys (utek) 2013-11-22
* Christian Benke (peletiah) 2017-02-19
* René Jochum (pcdummy) 2018-02-13
* Francis Charette Migneault (fmigneault) 2019-02-07
